==> eam-wshub-proxyclient-11.6-1-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/ContractAndRentalDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CONTRACTTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERID_Type;
import net.datastream.schemas.mp_fields.RENTALTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RENTALTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESERVATIONCALENDAROWNER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "isrental",
    "rentaltemplateid",
    "iscontract",
    "contracttemplateid",
    "customerid",
    "reservationcalendarowner"
})
@XmlRootElement(name = "ContractAndRentalDetails")
public class ContractAndRentalDetails {

    @XmlElement(name = "ISRENTAL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "RENTALTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected RENTALTEMPLATEID_Type rentaltemplateid;
    @XmlElement(name = "ISCONTRACT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "CONTRACTTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "RESERVATIONCALENDAROWNER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type reservationcalendarowner;

    /**
     * Obtient la valeur de la propriété isrental.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Définit la valeur de la propriété isrental.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Obtient la valeur de la propriété rentaltemplateid.
     * 
     * @return
     *     possible object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public RENTALTEMPLATEID_Type getRENTALTEMPLATEID() {
        return rentaltemplateid;
    }

    /**
     * Définit la valeur de la propriété rentaltemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public void setRENTALTEMPLATEID(RENTALTEMPLATEID_Type value) {
        this.rentaltemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété iscontract.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Définit la valeur de la propriété iscontract.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Obtient la valeur de la propriété contracttemplateid.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Définit la valeur de la propriété contracttemplateid.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Obtient la valeur de la propriété customerid.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Définit la valeur de la propriété customerid.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Obtient la valeur de la propriété reservationcalendarowner.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getRESERVATIONCALENDAROWNER() {
        return reservationcalendarowner;
    }

    /**
     * Définit la valeur de la propriété reservationcalendarowner.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setRESERVATIONCALENDAROWNER(USERID_Type value) {
        this.reservationcalendarowner = value;
    }

}

==> eam-wshub-proxyclient-12.0-sources.jar: net/datastream/schemas/mp_entities/equipmentconfiguration_001/ContractAndRentalDetails.java <==

package net.datastream.schemas.mp_entities.equipmentconfiguration_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.CONTRACTTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.CUSTOMERID_Type;
import net.datastream.schemas.mp_fields.RENTALTEMPLATEID_Type;
import net.datastream.schemas.mp_fields.USERID_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISRENTAL" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RENTALTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}ISCONTRACT" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CONTRACTTEMPLATEID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}CUSTOMERID" minOccurs="0"/>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}RESERVATIONCALENDAROWNER" minOccurs="0"/>
 *       &lt;/sequence>
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "isrental",
    "rentaltemplateid",
    "iscontract",
    "contracttemplateid",
    "customerid",
    "reservationcalendarowner"
})
@XmlRootElement(name = "ContractAndRentalDetails")
public class ContractAndRentalDetails {

    @XmlElement(name = "ISRENTAL", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String isrental;
    @XmlElement(name = "RENTALTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected RENTALTEMPLATEID_Type rentaltemplateid;
    @XmlElement(name = "ISCONTRACT", namespace = "http://schemas.datastream.net/MP_fields", defaultValue = "false")
    protected String iscontract;
    @XmlElement(name = "CONTRACTTEMPLATEID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CONTRACTTEMPLATEID_Type contracttemplateid;
    @XmlElement(name = "CUSTOMERID", namespace = "http://schemas.datastream.net/MP_fields")
    protected CUSTOMERID_Type customerid;
    @XmlElement(name = "RESERVATIONCALENDAROWNER", namespace = "http://schemas.datastream.net/MP_fields")
    protected USERID_Type reservationcalendarowner;

    /**
     * Gets the value of the isrental property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISRENTAL() {
        return isrental;
    }

    /**
     * Sets the value of the isrental property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISRENTAL(String value) {
        this.isrental = value;
    }

    /**
     * Gets the value of the rentaltemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public RENTALTEMPLATEID_Type getRENTALTEMPLATEID() {
        return rentaltemplateid;
    }

    /**
     * Sets the value of the rentaltemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link RENTALTEMPLATEID_Type }
     *     
     */
    public void setRENTALTEMPLATEID(RENTALTEMPLATEID_Type value) {
        this.rentaltemplateid = value;
    }

    /**
     * Gets the value of the iscontract property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getISCONTRACT() {
        return iscontract;
    }

    /**
     * Sets the value of the iscontract property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setISCONTRACT(String value) {
        this.iscontract = value;
    }

    /**
     * Gets the value of the contracttemplateid property.
     * 
     * @return
     *     possible object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public CONTRACTTEMPLATEID_Type getCONTRACTTEMPLATEID() {
        return contracttemplateid;
    }

    /**
     * Sets the value of the contracttemplateid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CONTRACTTEMPLATEID_Type }
     *     
     */
    public void setCONTRACTTEMPLATEID(CONTRACTTEMPLATEID_Type value) {
        this.contracttemplateid = value;
    }

    /**
     * Gets the value of the customerid property.
     * 
     * @return
     *     possible object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public CUSTOMERID_Type getCUSTOMERID() {
        return customerid;
    }

    /**
     * Sets the value of the customerid property.
     * 
     * @param value
     *     allowed object is
     *     {@link CUSTOMERID_Type }
     *     
     */
    public void setCUSTOMERID(CUSTOMERID_Type value) {
        this.customerid = value;
    }

    /**
     * Gets the value of the reservationcalendarowner property.
     * 
     * @return
     *     possible object is
     *     {@link USERID_Type }
     *     
     */
    public USERID_Type getRESERVATIONCALENDAROWNER() {
        return reservationcalendarowner;
    }

    /**
     * Sets the value of the reservationcalendarowner property.
     * 
     * @param value
     *     allowed object is
     *     {@link USERID_Type }
     *     
     */
    public void setRESERVATIONCALENDAROWNER(USERID_Type value) {
        this.reservationcalendarowner = value;
    }

}
